@@ -1,4 +1,4 @@
-# Copyright 2024 DARWIN EU®
+# Copyright 2025 DARWIN EU®
 #
 # This file is part of IncidencePrevalence
 #
@@ -31,22 +31,21 @@ getIncidence <- function(cdm,
                          analysisId,
                          strata,
                          includeOverallStrata) {
-
   if (!is.null(outcomeWashout) && is.na(outcomeWashout)) {
-      outcomeWashout <- NULL
-    }
+    outcomeWashout <- NULL
+  }
 
   ## Analysis code
   # people in the relevant denominator
   # along with their outcomes
   studyPop <- cdm[[denominatorTable]] %>%
     dplyr::filter(.data$cohort_definition_id ==
-                    .env$denominatorCohortId) %>%
+      .env$denominatorCohortId) %>%
     dplyr::select(-"cohort_definition_id") %>%
     dplyr::left_join(
       cdm[[outcomeTable]] %>%
         dplyr::filter(.data$outcome_cohort_id ==
-                        .env$outcomeCohortId) %>%
+          .env$outcomeCohortId) %>%
         dplyr::select(-"outcome_cohort_id"),
       by = c(
         "subject_id",
@@ -70,14 +69,14 @@ getIncidence <- function(cdm,
   # participants without an outcome
   studyPopNoOutcome <- studyPop %>%
     dplyr::filter(is.na(.data$outcome_start_date) &
-                  is.na(.data$outcome_prev_end_date))
+      is.na(.data$outcome_prev_end_date))
 
   # participants with an outcome
   # if outcome starts before cohort end date
   # update cohort_end_date
   studyPopOutcome <- studyPop %>%
     dplyr::filter(!is.na(.data$outcome_start_date) |
-                    !is.na(.data$outcome_prev_end_date)) %>%
+      !is.na(.data$outcome_prev_end_date)) %>%
     dplyr::mutate(cohort_end_date = dplyr::coalesce(
       .data$outcome_start_date,
       .data$cohort_end_date
@@ -89,24 +88,26 @@ getIncidence <- function(cdm,
     dplyr::pull("n")
 
 
-  if(nStudyPopOutcome > 0){
+  if (nStudyPopOutcome > 0) {
     if (is.null(outcomeWashout)) {
       # exclude anyone with a previous outcome
       studyPopOutcome <- studyPopOutcome %>%
         dplyr::filter(is.na(.data$outcome_prev_end_date) &
-                        .data$cohort_start_date <= .data$cohort_end_date)
+          .data$cohort_start_date <= .data$cohort_end_date)
     } else {
       # otherwise add the washout to the previous outcome
       outcomeWashoutPlusOne <- as.integer(outcomeWashout + 1)
       studyPopOutcome <- studyPopOutcome %>%
-        dplyr::mutate(outcome_prev_end_date =
-                        as.Date(.data$outcome_prev_end_date)) %>%
+        dplyr::mutate(
+          outcome_prev_end_date =
+            as.Date(.data$outcome_prev_end_date)
+        ) %>%
         dplyr::mutate(outcome_prev_end_date = dplyr::if_else(
           is.na(.data$outcome_prev_end_date),
           as.Date(.data$outcome_prev_end_date),
           as.Date(!!CDMConnector::dateadd("outcome_prev_end_date",
-                                          {{ outcomeWashoutPlusOne }},
-                                          interval = "day"
+            {{ outcomeWashoutPlusOne }},
+            interval = "day"
           ))
         )) %>%
         dplyr::mutate(cohort_start_date = dplyr::if_else(
@@ -117,8 +118,8 @@ getIncidence <- function(cdm,
         )) %>%
         dplyr::filter(.data$cohort_start_date <= .data$cohort_end_date)
       if (repeatedEvents == FALSE &&
-          sum(!is.na(studyPopOutcome %>%
-                     dplyr::pull(.data$outcome_start_date))) > 0) {
+        sum(!is.na(studyPopOutcome %>%
+          dplyr::pull(.data$outcome_start_date))) > 0) {
         studyPopOutcome <- studyPopOutcome %>%
           dplyr::group_by(.data$subject_id) %>%
           dplyr::mutate(events_post = sum(dplyr::if_else(
@@ -142,7 +143,7 @@ getIncidence <- function(cdm,
             dplyr::filter(.data$events_post >= 1) %>%
             dplyr::group_by(.data$subject_id) %>%
             dplyr::filter(.data$cohort_start_date ==
-                            min(.data$cohort_start_date, na.rm = TRUE)) %>%
+              min(.data$cohort_start_date, na.rm = TRUE)) %>%
             dplyr::ungroup()
         ) %>%
           dplyr::select(-"events_post")
@@ -156,7 +157,6 @@ getIncidence <- function(cdm,
         .data$outcome_start_date,
         .data$cohort_end_date
       ))
-
   }
 
   # combine those without an outcome back with those with an outcome
@@ -171,15 +171,15 @@ getIncidence <- function(cdm,
     reason = "Excluded due to prior event (do not pass outcome washout during study period)",
     existingAttrition = attrition
   )
-# intervals to estimate
-interval <- c(
-  "weeks" = weeks,
-  "months" = months,
-  "quarters" = quarters,
-  "years" = years,
-  "overall" = overall
-)
-interval <- names(interval[interval])
+  # intervals to estimate
+  interval <- c(
+    "weeks" = weeks,
+    "months" = months,
+    "quarters" = quarters,
+    "years" = years,
+    "overall" = overall
+  )
+  interval <- names(interval[interval])
 
   # study dates
   # based on the earliest start and latest end of those
@@ -232,17 +232,17 @@ interval <- names(interval[interval])
         end_time = startEnd$max
       )
     }
-  } else{
+  } else {
     # empty population
     studyDays[["none"]] <- dplyr::tibble()
   }
- if (nrow(dplyr::bind_rows(studyDays)) == 0) {
-   # no study days
+  if (nrow(dplyr::bind_rows(studyDays)) == 0) {
+    # no study days
     studyDays[["none"]] <- dplyr::tibble()
   }
 
   if ("none" %in% names(studyDays)) {
-    # if no study days we´ll return an empty tibble
+    # if no study days we<U+00B4>ll return an empty tibble
     ir <- dplyr::tibble()
 
     attrition <- recordAttrition(
@@ -257,10 +257,12 @@ interval <- names(interval[interval])
   if (!"none" %in% names(studyDays)) {
     # drop for complete database intervals requirement
     minStartDate <- min(dplyr::bind_rows(studyDays)$start_time)
-    maxStartDate <- max(dplyr::bind_rows(studyDays)$end_time )
+    maxStartDate <- max(dplyr::bind_rows(studyDays)$end_time)
     studyPop <- studyPop %>%
-      dplyr::filter(.data$cohort_end_date >= .env$minStartDate,
-                    .data$cohort_start_date <= .env$maxStartDate)
+      dplyr::filter(
+        .data$cohort_end_date >= .env$minStartDate,
+        .data$cohort_start_date <= .env$maxStartDate
+      )
 
     attrition <- recordAttrition(
       table = studyPop,
@@ -273,90 +275,98 @@ interval <- names(interval[interval])
     # fetch incidence rates
     # looping through each time interval
     ir <- list()
-    for(j in seq_along(interval)){
+    for (j in seq_along(interval)) {
       workingInterval <- interval[j]
       workingStudyDays <- studyDays[[workingInterval]]
-    for (i in seq_len(nrow(workingStudyDays))) {
-      workingStartTime <- workingStudyDays$start_time[i]
-      workingEndTime <- workingStudyDays$end_time[i]
+      for (i in seq_len(nrow(workingStudyDays))) {
+        workingStartTime <- workingStudyDays$start_time[i]
+        workingEndTime <- workingStudyDays$end_time[i]
 
-      # people who can contribute to the period
-      workingPop <- studyPop %>%
-        dplyr::filter(.data$cohort_end_date >= .env$workingStartTime,
-                      .data$cohort_start_date <= .env$workingEndTime)
+        # people who can contribute to the period
+        workingPop <- studyPop %>%
+          dplyr::filter(
+            .data$cohort_end_date >= .env$workingStartTime,
+            .data$cohort_start_date <= .env$workingEndTime
+          )
 
-      if (nrow(workingPop) > 0) {
-        # individuals start date for this period
-        # which could be start of the period or later
-        workingPop <- workingPop %>%
-          dplyr::mutate(tStart = dplyr::if_else(.data$cohort_start_date <= .env$workingStartTime,
-                                                as.Date(.env$workingStartTime),
-                                                as.Date(.data$cohort_start_date)
-          ),
-          # individuals end date for this period
-          # end of the period or earlier
-            tEnd =
-              dplyr::if_else(.data$cohort_end_date >= .env$workingEndTime,
-                             as.Date(.env$workingEndTime),
-                             as.Date(.data$cohort_end_date)
-              )
-          ) %>%
-          dplyr::mutate(workingDays = as.numeric(difftime(
-            .data$tEnd,
-            .data$tStart,
-            units = "days"
-          )) + 1)  %>%
-        # erase outcome_start_date if not during period
-          dplyr::mutate(outcome_start_date = dplyr::if_else(
-            .data$outcome_start_date <= .data$tEnd &
-              .data$outcome_start_date >= .data$tStart,
-            as.Date(.data$outcome_start_date),
-            as.Date(NA)
-          ))
-
-        if(length(strata)==0 || includeOverallStrata == TRUE){
-          ir[[paste0(i, "_", j)]] <- workingPop %>%
-            dplyr::summarise(
-              denominator_count = dplyr::n_distinct(.data$subject_id),
-              person_days = sum(.data$workingDays),
-              outcome_count = sum(!is.na(.data$outcome_start_date))
+        if (nrow(workingPop) > 0) {
+          # individuals start date for this period
+          # which could be start of the period or later
+          workingPop <- workingPop %>%
+            dplyr::mutate(
+              tStart = dplyr::if_else(.data$cohort_start_date <= .env$workingStartTime,
+                as.Date(.env$workingStartTime),
+                as.Date(.data$cohort_start_date)
+              ),
+              # individuals end date for this period
+              # end of the period or earlier
+              tEnd =
+                dplyr::if_else(.data$cohort_end_date >= .env$workingEndTime,
+                  as.Date(.env$workingEndTime),
+                  as.Date(.data$cohort_end_date)
+                )
             ) %>%
-            dplyr::mutate(incidence_start_date = .env$workingStartTime,
-                          incidence_end_date = .env$workingEndTime,
-                          analysis_interval = .env$workingInterval)
-        } else {
-          ir[[paste0(i, "_", j)]] <- dplyr::tibble()
-        }
+            dplyr::mutate(workingDays = as.numeric(difftime(
+              .data$tEnd,
+              .data$tStart,
+              units = "days"
+            )) + 1) %>%
+            # erase outcome_start_date if not during period
+            dplyr::mutate(outcome_start_date = dplyr::if_else(
+              .data$outcome_start_date <= .data$tEnd &
+                .data$outcome_start_date >= .data$tStart,
+              as.Date(.data$outcome_start_date),
+              as.Date(NA)
+            ))
 
-        if(length(strata)>=1){
-          ir[[paste0(i, "_", j)]] <- ir[[paste0(i, "_", j)]] %>%
-            omopgenerics::uniteStrata()
-          for(k in seq_along(strata)){
-            ir[[paste0(i, "_", j, "_", k)]] <-  dplyr::bind_rows(ir[[paste0(i, "_", j)]],
-                                  getStratifiedIncidenceResult(workingPop = workingPop,
-                                                                              workingStrata = strata[[k]],
-                                                                              workingStartTime = workingStartTime,
-                                                                              workingEndTime= workingEndTime,
-                                                                              workingInterval = workingInterval))
+          if (length(strata) == 0 || includeOverallStrata == TRUE) {
+            ir[[paste0(i, "_", j)]] <- workingPop %>%
+              dplyr::summarise(
+                denominator_count = dplyr::n_distinct(.data$subject_id),
+                person_days = sum(.data$workingDays),
+                outcome_count = sum(!is.na(.data$outcome_start_date))
+              ) %>%
+              dplyr::mutate(
+                incidence_start_date = .env$workingStartTime,
+                incidence_end_date = .env$workingEndTime,
+                analysis_interval = .env$workingInterval
+              )
+          } else {
+            ir[[paste0(i, "_", j)]] <- dplyr::tibble()
+          }
+
+          if (length(strata) >= 1) {
+            ir[[paste0(i, "_", j)]] <- ir[[paste0(i, "_", j)]] %>%
+              omopgenerics::uniteStrata()
+            for (k in seq_along(strata)) {
+              ir[[paste0(i, "_", j, "_", k)]] <- dplyr::bind_rows(
+                ir[[paste0(i, "_", j)]],
+                getStratifiedIncidenceResult(
+                  workingPop = workingPop,
+                  workingStrata = strata[[k]],
+                  workingStartTime = workingStartTime,
+                  workingEndTime = workingEndTime,
+                  workingInterval = workingInterval
+                )
+              )
+            }
           }
         }
-
       }
-    }}
-    ir <- dplyr::bind_rows(ir)
-    if(nrow(ir) > 0){
-    ir <- ir %>%
-      dplyr::mutate(
-        person_years = round(.data$person_days / 365.25, 3),
-        incidence_100000_pys =
-          round(((.data$outcome_count / .data$person_years) * 100000), 3)
-      )
     }
-
+    ir <- dplyr::bind_rows(ir)
+    if (nrow(ir) > 0) {
+      ir <- ir %>%
+        dplyr::mutate(
+          person_years = round(.data$person_days / 365.25, 3),
+          incidence_100000_pys =
+            round(((.data$outcome_count / .data$person_years) * 100000), 3)
+        )
+    }
   }
 
   # study design related variables
-  if(is.null(outcomeWashout)){
+  if (is.null(outcomeWashout)) {
     outcomeWashout <- "inf"
   }
   analysisSettings <- dplyr::tibble(
@@ -383,7 +393,7 @@ interval <- names(interval[interval])
 
 getStratifiedIncidenceResult <- function(workingPop, workingStrata,
                                          workingStartTime, workingEndTime,
-                                         workingInterval){
+                                         workingInterval) {
   workingPop %>%
     dplyr::group_by(dplyr::pick(.env$workingStrata)) %>%
     dplyr::summarise(
@@ -392,8 +402,10 @@ getStratifiedIncidenceResult <- function(workingPop, workingStrata,
       outcome_count = sum(!is.na(.data$outcome_start_date))
     ) %>%
     dplyr::ungroup() %>%
-    dplyr::mutate(incidence_start_date = .env$workingStartTime,
-                  incidence_end_date = .env$workingEndTime,
-                  analysis_interval = .env$workingInterval) %>%
+    dplyr::mutate(
+      incidence_start_date = .env$workingStartTime,
+      incidence_end_date = .env$workingEndTime,
+      analysis_interval = .env$workingInterval
+    ) %>%
     omopgenerics::uniteStrata(cols = workingStrata)
 }
