@@ -12,18 +12,20 @@ test_that("full benchmark", {
 
   timings <- benchmarkIncidencePrevalence(cdm)
   expect_true(is.data.frame(timings))
-  expect_true("summarised_result" %in%  class(timings))
-  expect_equal(colnames(timings),
-              colnames(omopgenerics::emptySummarisedResult()))
+  expect_true("summarised_result" %in% class(timings))
+  expect_equal(
+    colnames(timings),
+    colnames(omopgenerics::emptySummarisedResult())
+  )
 
   timings_only_inc <- benchmarkIncidencePrevalence(cdm,
-                                          analysisType = "only incidence"
+    analysisType = "only incidence"
   )
   expect_true(any(stringr::str_detect(timings_only_inc$group_level, "incidence")))
   expect_false(any(stringr::str_detect(timings_only_inc$group_level, "prevalence")))
 
   timings_only_prev <- benchmarkIncidencePrevalence(cdm,
-                                                   analysisType = "only prevalence"
+    analysisType = "only prevalence"
   )
   expect_false(any(stringr::str_detect(timings_only_prev$group_level, "incidence")))
   expect_true(any(stringr::str_detect(timings_only_prev$group_level, "prevalence")))
@@ -33,14 +35,13 @@ test_that("full benchmark", {
     cdm = "a"
   ))
   expect_error(benchmarkIncidencePrevalence(cdm,
-                                            analysisType = "not an option"
+    analysisType = "not an option"
   ))
 
-  CDMConnector::cdm_disconnect(cdm)
+  CDMConnector::cdmDisconnect(cdm)
 })
 
 test_that("check tables cleaned up", {
-
   cdm <- mockIncidencePrevalence(
     sampleSize = 100,
     earliestObservationStartDate = as.Date("2010-01-01"),
@@ -50,15 +51,17 @@ test_that("check tables cleaned up", {
   )
 
   start_tables <- CDMConnector::listTables(attr(attr(cdm, "cdm_source"), "dbcon"),
-                        schema = attr(attr(cdm, "cdm_source"), "write_schema"))
+    schema = attr(attr(cdm, "cdm_source"), "write_schema")
+  )
 
   timings <- benchmarkIncidencePrevalence(cdm)
 
   end_tables <- CDMConnector::listTables(attr(attr(cdm, "cdm_source"), "dbcon"),
-                                        schema = attr(attr(cdm, "cdm_source"), "write_schema"))
+    schema = attr(attr(cdm, "cdm_source"), "write_schema")
+  )
 
   expect_equal(sort(start_tables), sort(end_tables))
-  CDMConnector::cdm_disconnect(cdm)
+  CDMConnector::cdmDisconnect(cdm)
 
   cdm <- mockIncidencePrevalence(
     sampleSize = 100,
@@ -68,7 +71,5 @@ test_that("check tables cleaned up", {
     maxDaysToObservationEnd = 364
   )
 
-  CDMConnector::cdm_disconnect(cdm)
-
-
+  CDMConnector::cdmDisconnect(cdm)
 })
